---
title: '[릴리즈노트]2024-04-03 업데이트'
category: 업데이트
tags:
  - 관리자콘솔
  - 업데이트
searchTags:
  - 업데이트
  - 릴리즈노트
datetime: 2024-04-16T07:11:17.699Z
---

<Callout title="2024년 04월 03일 관리자콘솔 업데이트 소식을 안내드립니다." />



### 기타 수정사항

✔️ 결제 내역 엑셀 내의 카드유형 정보가 추가되었습니다.

\[결제 상세 내역 조회]에서 엑셀 다운로드시 신용카드, 체크카드, 기프트카드에 대한 정보가 표시됩니다.

#### **[\[관리자콘솔 릴리즈노트\] 2024-04-03 업데이트 보러가기↗](https://developers.portone.io/release-notes/console/2024-04-05?v=v1)**
